==> download.php?FileName=terralib-5.4.0.zip: share/terralib/translations/terralib_mod_qt_plugins_cellspace_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>CreateCellularSpaceDialogForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="14"/>
        <source>Create Cellular Space</source>
        <translation>Criar Espaço Celular</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="50"/>
        <source>Create Cellular Space Layer</source>
        <translation>Cria Camada como Espaço Celular</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="69"/>
        <source>Imagem</source>
        <translation>Imagem</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="79"/>
        <source>Input</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="121"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="419"/>
        <source>SRS:</source>
        <translation>SRS:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="161"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="210"/>
        <source>Mask</source>
        <translation>Máscara</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="229"/>
        <source>No Mask</source>
        <translation>Sem Máscara</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="266"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="309"/>
        <source>Points</source>
        <translation>Pontos</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="319"/>
        <source>Polygons</source>
        <translation>Polígonos</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="360"/>
        <source>Parameters</source>
        <translation>Parâmetros</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="368"/>
        <source>Bounding Box</source>
        <translation>Retangulo Envolvente</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="387"/>
        <source>Config the Map SRS</source>
        <translation>Configure o SRS do Mapa</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="390"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="720"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="461"/>
        <source>LL(x):</source>
        <translation>LL(x):</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="468"/>
        <source>UR(x):</source>
        <translation>UR(x):</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="475"/>
        <source>LL(y):</source>
        <translation>LL(y):</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="482"/>
        <source>UR(y):</source>
        <translation>UR(y):</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="542"/>
        <source>Dimension</source>
        <translation>Dimensão</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="555"/>
        <source>Resolution Unit:</source>
        <translation> Unidade Res:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="578"/>
        <source>Res. X:</source>
        <translation>Res X:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="585"/>
        <source>Res. Y:</source>
        <translation>Res. Y:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="592"/>
        <source>Cols:</source>
        <translation>Cols:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="599"/>
        <source>Rows:</source>
        <translation>Linhas:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="682"/>
        <source>Output</source>
        <translation>Saída</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="692"/>
        <source>Repository:</source>
        <translation>Repositório:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="717"/>
        <source>Set the output file path</source>
        <translation>Defina o caminho do arquivo de saída</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="733"/>
        <source>Select the data source</source>
        <translation>Selecione a Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="736"/>
        <source>BD</source>
        <translation>BD</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="749"/>
        <source>Layer Name:</source>
        <translation>Nome da Camada:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="781"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="804"/>
        <source>Create</source>
        <translation>Criar</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="811"/>
        <source>Cancel</source>
        <translation>Cancela</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::cellspace::CreateCellLayerAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellLayerAction.cpp" line="42"/>
        <source>Create Cell Layer...</source>
        <translation>Criar Espaço Celular...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellLayerAction.cpp" line="59"/>
        <source>Cellular Spaces</source>
        <translation>Espaço Celular</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellLayerAction.cpp" line="59"/>
        <source>Would you like to add the data in the tree?</source>
        <translation>Adicionar Camada na árvore?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::cellspace::CreateCellularSpaceDialog</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="237"/>
        <source>Choose the SRS</source>
        <translation>Defina o SRS</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="290"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="321"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="330"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="346"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="431"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="469"/>
        <source>Cellular Spaces</source>
        <translation>Espaço Celular</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="290"/>
        <source>There is no no spatial reference defined for the new cellular space. It is not possible to select a unit for the resolution.</source>
        <translation>Não foi definidio SRS para o novo espaço celular. Não é possivel selecionar a unidade de resolução.</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="321"/>
        <source>Unable to convert between the selected unit for the resolution and the unit of new cell layer SRS</source>
        <translation>Unidade da resolução e SRS de saída imcompativeis</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="330"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="346"/>
        <source>Invalid bounding box.</source>
        <translation>Retângulo Envolvene Inválido.</translation>
    </message>
    <message>
        <source>Shapefile (*.shp *.SHP);;</source>
        <translation type="vanished">Shapefile (*.shp, *.SHP);;</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation type="vanished">Salvar como ...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="402"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="407"/>
        <source>File information</source>
        <translation>Informação do arquivo</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="407"/>
        <source>Output layer is invalid.</source>
        <translation>Camada de saída está inválida.</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="684"/>
        <source>Consistency errors:</source>
        <translation>Erros de consistência:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="689"/>
        <source>Invalid bounding box</source>
        <translation>Retângulo Envolvene Inválido</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="698"/>
        <source>X resolution must be greater than 0 and smaller than the bounding box Width </source>
        <translation>Res X deve ser maior que 0 e menor que a Largura do retangulo envolvente </translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="707"/>
        <source>Y resolution must be greater than 0 and smaller than the bounding box Height </source>
        <translation>Res Y deve ser maior que 0 e menor que a Altura do retangulo envolvente </translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="714"/>
        <source>Output layer name is empty</source>
        <translation>Nome da saída está vazio</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="724"/>
        <source>Reference layer and output layer have incompatible SRSs. It is not possible to create cells using polygons as masks.</source>
        <translation>Camada de referencia e Saída tem SRSs incompatíveis. Não foi possível criar Celulas usando polígonos como máscara.</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::cellspace::Plugin</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/Plugin.cpp" line="66"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/Plugin.cpp" line="74"/>
        <source>Cellular Spaces</source>
        <translation>Espaço Celular</translation>
    </message>
</context>
</TS>

==> download.php?FileName=terralib-5.5.0.zip: share/terralib/translations/terralib_mod_qt_plugins_cellspace_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>CreateCellularSpaceDialogForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="14"/>
        <source>Create Cellular Space</source>
        <translation>Criar Espaço Celular</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="50"/>
        <source>Create Cellular Space Layer</source>
        <translation>Cria Camada como Espaço Celular</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="69"/>
        <source>Imagem</source>
        <translation>Imagem</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="79"/>
        <source>Input</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="121"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="419"/>
        <source>SRS:</source>
        <translation>SRS:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="161"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="210"/>
        <source>Mask</source>
        <translation>Máscara</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="229"/>
        <source>No Mask</source>
        <translation>Sem Máscara</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="266"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="309"/>
        <source>Points</source>
        <translation>Pontos</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="319"/>
        <source>Polygons</source>
        <translation>Polígonos</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="360"/>
        <source>Parameters</source>
        <translation>Parâmetros</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="368"/>
        <source>Bounding Box</source>
        <translation>Retangulo Envolvente</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="387"/>
        <source>Config the Map SRS</source>
        <translation>Configure o SRS do Mapa</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="390"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="720"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="461"/>
        <source>LL(x):</source>
        <translation>LL(x):</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="468"/>
        <source>UR(x):</source>
        <translation>UR(x):</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="475"/>
        <source>LL(y):</source>
        <translation>LL(y):</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="482"/>
        <source>UR(y):</source>
        <translation>UR(y):</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="542"/>
        <source>Dimension</source>
        <translation>Dimensão</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="555"/>
        <source>Resolution Unit:</source>
        <translation> Unidade Res:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="578"/>
        <source>Res. X:</source>
        <translation>Res X:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="585"/>
        <source>Res. Y:</source>
        <translation>Res. Y:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="592"/>
        <source>Cols:</source>
        <translation>Cols:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="599"/>
        <source>Rows:</source>
        <translation>Linhas:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="682"/>
        <source>Output</source>
        <translation>Saída</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="692"/>
        <source>Repository:</source>
        <translation>Repositório:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="717"/>
        <source>Set the output file path</source>
        <translation>Defina o caminho do arquivo de saída</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="733"/>
        <source>Select the data source</source>
        <translation>Selecione a Fonte de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="736"/>
        <source>BD</source>
        <translation>BD</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="749"/>
        <source>Layer Name:</source>
        <translation>Nome da Camada:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="781"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="804"/>
        <source>Create</source>
        <translation>Criar</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/ui/CreateCellularSpaceDialogForm.ui" line="811"/>
        <source>Cancel</source>
        <translation>Cancela</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::cellspace::CreateCellLayerAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellLayerAction.cpp" line="42"/>
        <source>Create Cell Layer...</source>
        <translation>Criar Espaço Celular...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellLayerAction.cpp" line="59"/>
        <source>Cellular Spaces</source>
        <translation>Espaço Celular</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellLayerAction.cpp" line="59"/>
        <source>Would you like to add the data in the tree?</source>
        <translation>Adicionar Camada na árvore?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::cellspace::CreateCellularSpaceDialog</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="237"/>
        <source>Choose the SRS</source>
        <translation>Defina o SRS</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="290"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="321"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="330"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="346"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="431"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="469"/>
        <source>Cellular Spaces</source>
        <translation>Espaço Celular</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="290"/>
        <source>There is no no spatial reference defined for the new cellular space. It is not possible to select a unit for the resolution.</source>
        <translation>Não foi definidio SRS para o novo espaço celular. Não é possivel selecionar a unidade de resolução.</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="321"/>
        <source>Unable to convert between the selected unit for the resolution and the unit of new cell layer SRS</source>
        <translation>Unidade da resolução e SRS de saída imcompativeis</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="330"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="346"/>
        <source>Invalid bounding box.</source>
        <translation>Retângulo Envolvene Inválido.</translation>
    </message>
    <message>
        <source>Shapefile (*.shp *.SHP);;</source>
        <translation type="obsolete">Shapefile (*.shp, *.SHP);;</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation type="obsolete">Salvar como ...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="402"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="407"/>
        <source>File information</source>
        <translation>Informação do arquivo</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="407"/>
        <source>Output layer is invalid.</source>
        <translation>Camada de saída está inválida.</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="684"/>
        <source>Consistency errors:</source>
        <translation>Erros de consistência:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="689"/>
        <source>Invalid bounding box</source>
        <translation>Retângulo Envolvene Inválido</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="698"/>
        <source>X resolution must be greater than 0 and smaller than the bounding box Width </source>
        <translation>Res X deve ser maior que 0 e menor que a Largura do retangulo envolvente </translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="707"/>
        <source>Y resolution must be greater than 0 and smaller than the bounding box Height </source>
        <translation>Res Y deve ser maior que 0 e menor que a Altura do retangulo envolvente </translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="714"/>
        <source>Output layer name is empty</source>
        <translation>Nome da saída está vazio</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/CreateCellularSpaceDialog.cpp" line="724"/>
        <source>Reference layer and output layer have incompatible SRSs. It is not possible to create cells using polygons as masks.</source>
        <translation>Camada de referencia e Saída tem SRSs incompatíveis. Não foi possível criar Celulas usando polígonos como máscara.</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::cellspace::Plugin</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/cellspace/Plugin.cpp" line="66"/>
        <location filename="../../../src/terralib/qt/plugins/cellspace/Plugin.cpp" line="74"/>
        <source>Cellular Spaces</source>
        <translation>Espaço Celular</translation>
    </message>
</context>
</TS>
